from setuptools import setup

setup(name='norm_binom_distribution',
      version='0.11',
      description='Gaussian & Binomial distributions',
      packages=['norm_binom_distribution'],
      zip_safe=False)
